@@ -1,5 +1,8 @@
 from pymarc import Indicators
-import os
+
+YYMMDD_FORMAT = "%y%m%d"
+YYYYMMDD_FORMAT = "%Y%m%d"
+YY_DD_FORMAT = "%Y-%m"
 
 class EntityType:
     PER = "PER"
