@@ -1,5 +1,6 @@
 import requests
 import json
+import unicodedata
 import regex as re
 from typing import List, Dict
 from collections import defaultdict
@@ -10,6 +11,7 @@ from rara_tools.constants.normalizers import (
     DEFAULT_VIAF_FIELD, ALLOWED_VIAF_FIELDS, ALLOWED_VIAF_WIKILINK_LANGS,
     VIAF_SIMILARITY_THRESHOLD, VIAF_ALLOWED_SOURCES
 )
+from glom import glom
 
 import logging
 logger = logging.getLogger(__name__)
@@ -160,10 +162,14 @@ class VIAFRecord:
         )
         names = []
         for n in name_list:
-            _name = self._strip_punctuation(n[0])
-            if _name not in names:
-                names.append(_name)
-
+            try:
+                _name = self._strip_punctuation(n[0])
+                if _name not in names:
+                    names.append(_name)
+            except Exception as e:
+                logger.debug(
+                    f"Failed stripping punctuation from entity '{n[0]}' with error: {e}. Skipping it."
+                )
         return names
 
     def _get_name(self, marc_dicts: List[dict]) -> str:
@@ -452,6 +458,32 @@ class VIAFClient:
             logger.error(f"VIAF ID query has changed or not working!")
         return success
 
+    @staticmethod
+    def normalize_latin(s: str) -> str:
+        # Map characters whose ASCII equivalents are not produced by NFKD
+        FALLBACKS = {
+            "Ł": "L", "ł": "l",
+            "Ø": "O", "ø": "o",
+            "Þ": "Th", "þ": "th",
+            "Ð": "D", "ð": "d",
+            "Æ": "AE", "æ": "ae",
+            "Œ": "OE", "œ": "oe",
+            "ß": "ss",
+        }
+        # Apply fallbacks first
+        s = "".join(FALLBACKS.get(c, c) for c in s)
+
+        # Normalize via Unicode
+        s = unicodedata.normalize("NFKD", s)
+
+        # Remove combining marks
+        s = "".join(c for c in s if unicodedata.category(c) != "Mn")
+
+        # Finally strip any remaining non-ASCII
+        s = ''.join(c for c in s if ord(c) < 128)
+        return s
+
+
     @staticmethod
     def verify(entity: str, viaf_record: VIAFRecord,
             threshold: float = VIAF_SIMILARITY_THRESHOLD
@@ -497,7 +529,11 @@ class VIAFClient:
         verified = False
         for var in viaf_record.name_variations:
             for name_form in name_forms:
-                score = jw(name_form.lower(), var.lower())
+                # Remove various accents, so they wouldn`t
+                # influence the simialrity scores
+                s1 = VIAFClient.normalize_latin(name_form.lower())
+                s2 = VIAFClient.normalize_latin(var.lower())
+                score = jw(s1, s2)
                 if score > max_similarity:
                     max_similarity = score
                     most_similar_record = var
@@ -598,11 +634,13 @@ class VIAFClient:
         """
         logger.debug("Extracting VIAF IDs from VIAF search query results.")
         try:
-            records = search_query_response.json()["queryResult"]["records"]["record"]
+            res_json = search_query_response.json()
+            records = glom(res_json, "queryResult.records.record", default=[])
+
         except Exception as e:
             logger.error(
                 f"Parsing records from search query " \
-                f"response failed with error: {e}."
+                f"failed with error: {e}."
             )
             records = []
         viaf_ids = []
